@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
-our $DATE = '2016-03-09'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 our @Module_Lists = (
     {
@@ -57,8 +57,8 @@ _
                 summary => 'Unnecessary, use Exporter instead',
                 description => <<'_',
 
-I used to use this module because I didn't know that `Exporter` can also be used
-without subclassing, i.e. instead of:
+I used to use this module because I didn't know that `Exporter` (since perl
+5.8.3, 2004) can also be used without subclassing, i.e. instead of:
 
     use Exporter;
     our @ISA = qw(Exporter);
@@ -69,6 +69,10 @@ you can also use it like this:
     use Exporter qw(import);
     our @EXPORT = (...);
 
+Hence, this module (first released in 2001) is no longer necessary. Besides,
+this module has a worse startup overhead than `Exporter` *and* has less
+features. So there is absolutely no reason to use it.
+
 _
                 alternate_modules => ['Exporter'],
             },
@@ -115,7 +119,7 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.13 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
+This document describes version 0.14 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-16.
 
 =head1 MODULE LISTS
 
@@ -160,8 +164,8 @@ Alternate modules: L<File::Slurper>
 
 =item * L<Exporter::Lite> - Unnecessary, use Exporter instead
 
-I used to use this module because I didn't know that C<Exporter> can also be used
-without subclassing, i.e. instead of:
+I used to use this module because I didn't know that C<Exporter> (since perl
+5.8.3, 2004) can also be used without subclassing, i.e. instead of:
 
  use Exporter;
  our @ISA = qw(Exporter);
@@ -172,6 +176,10 @@ you can also use it like this:
  use Exporter qw(import);
  our @EXPORT = (...);
 
+Hence, this module (first released in 2001) is no longer necessary. Besides,
+this module has a worse startup overhead than C<Exporter> I<and> has less
+features. So there is absolutely no reason to use it.
+
 
 Alternate modules: L<Exporter>
 
