@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Retired;
 
-our $DATE = '2016-03-09'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 our @Module_Lists = (
     # list: Retired modules
@@ -33,6 +33,9 @@ _
                 module => 'Carp::Always::Dump',
                 description => <<'_',
 
+This module is like `Carp::Always`, but dumps complex arguments instead of just
+printing `ARRAY(0x22f8160)` or something like that.
+
 Superseded by `Devel::Confess`, which can do color (`Carp::Always::Color`),
 dumps (`Carp::Always::Dump`), as well as a few other tricks, all in a single
 package.
@@ -70,7 +73,7 @@ Acme::CPANLists::PERLANCAR::Retired - Retired modules
 
 =head1 VERSION
 
-This document describes version 0.13 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-09.
+This document describes version 0.14 of Acme::CPANLists::PERLANCAR::Retired (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-03-16.
 
 =head1 MODULE LISTS
 
@@ -97,6 +100,9 @@ Alternate modules: L<Data::Sah>
 
 =item * L<Carp::Always::Dump>
 
+This module is like C<Carp::Always>, but dumps complex arguments instead of just
+printing C<ARRAY(0x22f8160)> or something like that.
+
 Superseded by C<Devel::Confess>, which can do color (C<Carp::Always::Color>),
 dumps (C<Carp::Always::Dump>), as well as a few other tricks, all in a single
 package.
